# Change Log

## Unreleased

* Fix: Drop support for python 3.9, add for 3.12 (@lwasser, #15)
* Add: Code of conduct to repo following contributors covenant (@lwasser, #17)
* Add: Linting & code format using ruff / precommit (@lwasser, #19)

## 0.1.10

* Initial publish to PyPI & Conda forge

## 0.1.9

* Use Hatch

## 0.1.8

* Fix: License should be MIT throughout

## 0.1.7

* Fix: Python version should be >3.9

## 0.1.6

* Fix: Add `readme` and `pyproject.toml` file
